# Levent Tools Package
leventools is a package for miscellaneous tools for data science and python

## Installation
Pull this repo and run below command in top folder
```
pip install .
```

## Usage
Import modules and run/use methods
```
from leventools.data_science.eda import identify_outliers
```

## License
MIT License Copyright (c) 2022 Levent Soykan


